==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/outputs/AzureBlobDatasetResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.outputs

import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 * The Azure Blob storage.
 * @property annotations List of tags that can be used for describing the Dataset.
 * @property compression The data compression method used for the blob storage.
 * @property description Dataset description.
 * @property fileName The name of the Azure Blob. Type: string (or Expression with resultType string).
 * @property folder The folder that this Dataset is in. If not specified, Dataset will appear at the root level.
 * @property folderPath The path of the Azure Blob storage. Type: string (or Expression with resultType string).
 * @property format The format of the Azure Blob storage.
 * @property linkedServiceName Linked service reference.
 * @property modifiedDatetimeEnd The end of Azure Blob's modified datetime. Type: string (or Expression with resultType string).
 * @property modifiedDatetimeStart The start of Azure Blob's modified datetime. Type: string (or Expression with resultType string).
 * @property parameters Parameters for dataset.
 * @property schema Columns that define the physical type schema of the dataset. Type: array (or Expression with resultType array), itemType: DatasetSchemaDataElement.
 * @property structure Columns that define the structure of the dataset. Type: array (or Expression with resultType array), itemType: DatasetDataElement.
 * @property tableRootLocation The root of blob path. Type: string (or Expression with resultType string).
 * @property type Type of dataset.
 * Expected value is 'AzureBlob'.
 */
public data class AzureBlobDatasetResponse(
    public val annotations: List<Any>? = null,
    public val compression: DatasetCompressionResponse? = null,
    public val description: String? = null,
    public val fileName: Any? = null,
    public val folder: DatasetResponseFolder? = null,
    public val folderPath: Any? = null,
    public val format: Any? = null,
    public val linkedServiceName: LinkedServiceReferenceResponse,
    public val modifiedDatetimeEnd: Any? = null,
    public val modifiedDatetimeStart: Any? = null,
    public val parameters: Map<String, ParameterSpecificationResponse>? = null,
    public val schema: Any? = null,
    public val structure: Any? = null,
    public val tableRootLocation: Any? = null,
    public val type: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.datafactory.outputs.AzureBlobDatasetResponse):
            AzureBlobDatasetResponse = AzureBlobDatasetResponse(
            annotations = javaType.annotations().map({ args0 -> args0 }),
            compression = javaType.compression().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.datafactory.kotlin.outputs.DatasetCompressionResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            description = javaType.description().map({ args0 -> args0 }).orElse(null),
            fileName = javaType.fileName().map({ args0 -> args0 }).orElse(null),
            folder = javaType.folder().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.datafactory.kotlin.outputs.DatasetResponseFolder.Companion.toKotlin(args0)
                })
            }).orElse(null),
            folderPath = javaType.folderPath().map({ args0 -> args0 }).orElse(null),
            format = javaType.format().map({ args0 -> args0 }).orElse(null),
            linkedServiceName = javaType.linkedServiceName().let({ args0 ->
                com.pulumi.azurenative.datafactory.kotlin.outputs.LinkedServiceReferenceResponse.Companion.toKotlin(args0)
            }),
            modifiedDatetimeEnd = javaType.modifiedDatetimeEnd().map({ args0 -> args0 }).orElse(null),
            modifiedDatetimeStart = javaType.modifiedDatetimeStart().map({ args0 -> args0 }).orElse(null),
            parameters = javaType.parameters().map({ args0 ->
                args0.key.to(
                    args0.value.let({ args0 ->
                        com.pulumi.azurenative.datafactory.kotlin.outputs.ParameterSpecificationResponse.Companion.toKotlin(args0)
                    }),
                )
            }).toMap(),
            schema = javaType.schema().map({ args0 -> args0 }).orElse(null),
            structure = javaType.structure().map({ args0 -> args0 }).orElse(null),
            tableRootLocation = javaType.tableRootLocation().map({ args0 -> args0 }).orElse(null),
            type = javaType.type(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/outputs/AzureBlobDatasetResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.outputs

import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 * The Azure Blob storage.
 * @property annotations List of tags that can be used for describing the Dataset.
 * @property compression The data compression method used for the blob storage.
 * @property description Dataset description.
 * @property fileName The name of the Azure Blob. Type: string (or Expression with resultType string).
 * @property folder The folder that this Dataset is in. If not specified, Dataset will appear at the root level.
 * @property folderPath The path of the Azure Blob storage. Type: string (or Expression with resultType string).
 * @property format The format of the Azure Blob storage.
 * @property linkedServiceName Linked service reference.
 * @property modifiedDatetimeEnd The end of Azure Blob's modified datetime. Type: string (or Expression with resultType string).
 * @property modifiedDatetimeStart The start of Azure Blob's modified datetime. Type: string (or Expression with resultType string).
 * @property parameters Parameters for dataset.
 * @property schema Columns that define the physical type schema of the dataset. Type: array (or Expression with resultType array), itemType: DatasetSchemaDataElement.
 * @property structure Columns that define the structure of the dataset. Type: array (or Expression with resultType array), itemType: DatasetDataElement.
 * @property tableRootLocation The root of blob path. Type: string (or Expression with resultType string).
 * @property type Type of dataset.
 * Expected value is 'AzureBlob'.
 */
public data class AzureBlobDatasetResponse(
    public val annotations: List<Any>? = null,
    public val compression: DatasetCompressionResponse? = null,
    public val description: String? = null,
    public val fileName: Any? = null,
    public val folder: DatasetResponseFolder? = null,
    public val folderPath: Any? = null,
    public val format: Any? = null,
    public val linkedServiceName: LinkedServiceReferenceResponse,
    public val modifiedDatetimeEnd: Any? = null,
    public val modifiedDatetimeStart: Any? = null,
    public val parameters: Map<String, ParameterSpecificationResponse>? = null,
    public val schema: Any? = null,
    public val structure: Any? = null,
    public val tableRootLocation: Any? = null,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.datafactory.outputs.AzureBlobDatasetResponse): AzureBlobDatasetResponse = AzureBlobDatasetResponse(
            annotations = javaType.annotations().map({ args0 -> args0 }),
            compression = javaType.compression().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.datafactory.kotlin.outputs.DatasetCompressionResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            description = javaType.description().map({ args0 -> args0 }).orElse(null),
            fileName = javaType.fileName().map({ args0 -> args0 }).orElse(null),
            folder = javaType.folder().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.datafactory.kotlin.outputs.DatasetResponseFolder.Companion.toKotlin(args0)
                })
            }).orElse(null),
            folderPath = javaType.folderPath().map({ args0 -> args0 }).orElse(null),
            format = javaType.format().map({ args0 -> args0 }).orElse(null),
            linkedServiceName = javaType.linkedServiceName().let({ args0 ->
                com.pulumi.azurenative.datafactory.kotlin.outputs.LinkedServiceReferenceResponse.Companion.toKotlin(args0)
            }),
            modifiedDatetimeEnd = javaType.modifiedDatetimeEnd().map({ args0 -> args0 }).orElse(null),
            modifiedDatetimeStart = javaType.modifiedDatetimeStart().map({ args0 -> args0 }).orElse(null),
            parameters = javaType.parameters().map({ args0 ->
                args0.key.to(
                    args0.value.let({ args0 ->
                        com.pulumi.azurenative.datafactory.kotlin.outputs.ParameterSpecificationResponse.Companion.toKotlin(args0)
                    }),
                )
            }).toMap(),
            schema = javaType.schema().map({ args0 -> args0 }).orElse(null),
            structure = javaType.structure().map({ args0 -> args0 }).orElse(null),
            tableRootLocation = javaType.tableRootLocation().map({ args0 -> args0 }).orElse(null),
            type = javaType.type(),
        )
    }
}
